@@ -2,7 +2,6 @@
 
 use strict;
 use warnings;
-use v5.10;
 use AnyEvent;
 use AnyEvent::Finger qw( finger_client );
 
@@ -10,11 +9,13 @@ my $done = AnyEvent->condvar;
 
 finger_client 'localhost', shift @ARGV, sub {
   my($lines) = @_;
-  say "[response]";
-  say join "\n", @$lines;
+  print "[response]\n";
+  print join "\n", @$lines;
+  print "\n";
   $done->send;
 }, on_error => sub {
-  say STDERR shift;
+  print STDERR shift;
+  print STDERR "\n";
   $done->send;
 };
 
