@@ -2,12 +2,9 @@ package AnyEvent::Finger::Transaction;
 
 use strict;
 use warnings;
-use overload
-  '""' => sub { shift->as_string },
-  bool => sub { 1 }, fallback => 1;
 
 # ABSTRACT: Simple asynchronous finger transaction
-our $VERSION = '0.12'; # VERSION
+our $VERSION = '0.14'; # VERSION
 
 
 sub res { shift->{res} }
@@ -34,7 +31,7 @@ AnyEvent::Finger::Transaction - Simple asynchronous finger transaction
 
 =head1 VERSION
 
-version 0.12
+version 0.14
 
 =head1 DESCRIPTION
 
@@ -104,7 +101,7 @@ Graham Ollis <plicease@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2012-2021 by Graham Ollis.
+This software is copyright (c) 2012-2022 by Graham Ollis.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
